@@ -125,6 +125,7 @@ QVariantHash labelVariantHash()
     hash.insert( TAG( "WEBSITE"), i18nc("Printed on the document", "Website"));
 
     hash.insert( TAG( "PAGE"), i18nc("Printed on the document", "Page"));
+    hash.insert( TAG( "PREDECESSOR"), i18nc("Label of Predecessor document number", "Predecessor-Doc"));
     hash.insert( TAG( "PAGE_OF"), i18nc("the 'of' in page X of Y", "of"));
     hash.insert( TAG( "DOC_NO"), i18nc("Document number on document", "Document No."));
     hash.insert( TAG( "DATE"), i18nc("Date on document", "Date"));
@@ -232,8 +233,8 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
 
         tmpl.setValue( DICT("POSITIONS"), TAG("POS_AMOUNT"), h );
         tmpl.setValue( DICT("POSITIONS"), TAG("POS_UNIT"), escapeTrml2pdfXML( pos.unit() ) );
-        tmpl.setValue( DICT("POSITIONS"), TAG("POS_UNITPRICE"), pos.unitPrice().toString() );
-        tmpl.setValue( DICT("POSITIONS"), TAG("POS_TOTAL"), pos.nettoPrice().toString() );
+        tmpl.setValue( DICT("POSITIONS"), TAG("POS_UNITPRICE"), pos.unitPrice().toLocaleString() );
+        tmpl.setValue( DICT("POSITIONS"), TAG("POS_TOTAL"), pos.nettoPrice().toLocaleString() );
         tmpl.setValue( DICT("POSITIONS"), TAG("POS_KIND"), pos.kind().toLower() );
 
         QString taxType;
@@ -297,7 +298,7 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
 
     /* now replace stuff in the whole document */
     tmpl.setValue( TAG( "DATE" ), Format::toDateString(archDoc->date(), KraftSettings::self()->dateFormat()));
-    tmpl.setValue( TAG( "DOCTYPE" ), escapeTrml2pdfXML( archDoc->docType() ) );
+    tmpl.setValue( TAG( "DOCTYPE" ), escapeTrml2pdfXML( archDoc->docTypeStr() ) );
     tmpl.setValue( TAG( "ADDRESS" ), escapeTrml2pdfXML( archDoc->address() ) );
 
     contactToTemplate( tmpl, "CLIENT", customerContact );
@@ -309,15 +310,15 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
     tmpl.setValue( TAG( "GOODBYE" ), escapeTrml2pdfXML( archDoc->goodbye() ) );
     tmpl.setValue( TAG( "PRETEXT" ),   rmlString( archDoc->preText() ) );
     tmpl.setValue( TAG( "POSTTEXT" ),  rmlString( archDoc->postText() ) );
-    tmpl.setValue( TAG( "BRUTTOSUM" ), archDoc->bruttoSum().toString() );
-    tmpl.setValue( TAG( "NETTOSUM" ),  archDoc->nettoSum().toString() );
+    tmpl.setValue( TAG( "BRUTTOSUM" ), archDoc->bruttoSum().toLocaleString() );
+    tmpl.setValue( TAG( "NETTOSUM" ),  archDoc->nettoSum().toLocaleString() );
 
     h = DefaultProvider::self()->locale()->toString( archDoc->tax() );
     // qDebug () << "Tax in archive document: " << h;
     if ( archDoc->reducedTaxSum().toLong() != 0 ) {
         tmpl.createDictionary( DICT( "SECTION_REDUCED_TAX" ) );
         tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX_SUM" ),
-                       archDoc->reducedTaxSum().toString() );
+                       archDoc->reducedTaxSum().toLocaleString() );
         h = DefaultProvider::self()->locale()->toString( archDoc->reducedTax() );
         tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX" ), h );
         tmpl.setValue( DICT("SECTION_REDUCED_TAX"), TAG( "REDUCED_TAX_LABEL" ), i18n( "reduced VAT" ) );
@@ -325,7 +326,7 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
     if ( archDoc->fullTaxSum().toLong() != 0 ) {
         tmpl.createDictionary( DICT( "SECTION_FULL_TAX" ) );
         tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX_SUM" ),
-                       archDoc->fullTaxSum().toString() );
+                       archDoc->fullTaxSum().toLocaleString() );
         h = DefaultProvider::self()->locale()->toString( archDoc->tax() );
         tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX" ), h );
         tmpl.setValue( DICT("SECTION_FULL_TAX"), TAG( "FULL_TAX_LABEL" ), i18n( "VAT" ) );
@@ -334,7 +335,7 @@ const QString CTemplateDocumentTemplate::expand(ArchDoc *archDoc, const KContact
     h = DefaultProvider::self()->locale()->toString( archDoc->tax() );
     tmpl.setValue( TAG( "VAT" ), h );
 
-    tmpl.setValue( TAG( "VATSUM" ), archDoc->taxSum().toString() );
+    tmpl.setValue( TAG( "VATSUM" ), archDoc->taxSum().toLocaleString() );
 
     addLabelsToTemplate(tmpl);
 
@@ -370,6 +371,7 @@ const QString GrantleeDocumentTemplate::expand( ArchDoc *archDoc,
     if (_errorStr.isEmpty()) {
 
         GrantleeFileTemplate gtmpl(_tmplFile);
+
         gtmpl.addToObjMapping("doc", archDoc);
 
         gtmpl.addToMapping(QStringLiteral("me"), contactToVariantHash(myContact));
