@@ -84,9 +84,9 @@ FlosTemplDialog::FlosTemplDialog( QWidget *parent, bool modal )
   m_gbPriceSrc->addButton(m_rbManual, 0);
   m_gbPriceSrc->addButton(m_rbCalculation, 1);
 
-  m_timeParts->header()->setResizeMode(QHeaderView::ResizeToContents);
-  m_fixParts->header()->setResizeMode(QHeaderView::ResizeToContents);
-  m_matParts->header()->setResizeMode(QHeaderView::ResizeToContents);
+  m_timeParts->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
+  m_fixParts->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
+  m_matParts->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
   // disable for now, not used
   cbMwst->setVisible(false);
@@ -274,19 +274,19 @@ void FlosTemplDialog::refreshPrices()
   m_resPreisName->setTextFormat(Qt::RichText);
 
   /* set Price */
-  t = m_template->unitPrice().toString();
+  t = m_template->unitPrice().toLocaleString();
   m_resultPrice->setText( t );
   m_manualPriceVal->setValue( m_template->unitPrice().toDouble() );
 
   /* Price parts per calculation part */
   Geld g( m_template->costsByCalcPart( KALKPART_TIME ));
-  m_textTimePart->setText( g.toString());
+  m_textTimePart->setText( g.toLocaleString());
 
   g = m_template->costsByCalcPart( KALKPART_FIX );
-  m_textFixPart->setText( g.toString());
+  m_textFixPart->setText( g.toLocaleString());
 
   g = m_template->costsByCalcPart( KALKPART_MATERIAL );
-  m_textMaterialPart->setText(g.toString());
+  m_textMaterialPart->setText(g.toLocaleString());
 
   // Benefit
   double b = m_template->getBenefit();
@@ -611,8 +611,8 @@ void FlosTemplDialog::drawFixListEntry( QTreeWidgetItem* it, FixCalcPart *cp )
 
   it->setText( 0, DefaultProvider::self()->locale()->toString(cp->getMenge()));
   it->setText( 1, cp->getName());
-  it->setText( 2, cp->unitPreis().toString());
-  it->setText( 3, cp->basisKosten().toString());
+  it->setText( 2, cp->unitPreis().toLocaleString());
+  it->setText( 3, cp->basisKosten().toLocaleString());
 }
 
 void FlosTemplDialog::drawMatListEntry( QTreeWidgetItem *it, MaterialCalcPart *mc )
@@ -620,9 +620,9 @@ void FlosTemplDialog::drawMatListEntry( QTreeWidgetItem *it, MaterialCalcPart *m
   it->setText( 0, mc->getName());
   it->setText( 1, QString::number(mc->getCalcAmount(), 'f',2));
   it->setText( 2, mc->getMaterial()->unit().einheitSingular());
-  it->setText( 3, mc->basisKosten().toString());
+  it->setText( 3, mc->basisKosten().toLocaleString());
   it->setText( 4, QString::number(mc->getMaterial()->getAmountPerPack(), 'f',2));
-  it->setText( 5, mc->getMaterial()->salesPrice().toString());
+  it->setText( 5, mc->getMaterial()->salesPrice().toLocaleString());
 }
 
 
