@@ -281,7 +281,8 @@ void KraftView::slotLinkClicked(const QString& link)
 {
     QUrl u(link);
     if( u.scheme() == "doc" && u.host() == "show" ) {
-        const QString ident = u.queryItemValue("id");
+        QUrlQuery uq(link);
+        const QString ident = uq.queryItemValue("id");
         qDebug() << "Link clicked to open document " << ident;
         emit openROView( ident );
     }
@@ -1022,14 +1023,13 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl, const QString&
                     defaultKat->load();
                     KatalogMan::self()->notifyKatalogChange( defaultKat , dbID() );
                 }
+            } else if (!newTemplate && tmpl){
+                tmplId = static_cast<FloskelTemplate*>(tmpl)->getTemplID();
+            }
+        } else if ( kat->type() == MaterialCatalog ) {
+            if ( !newTemplate ) {
+                tmplId = static_cast<StockMaterial*>(tmpl)->getID();
             }
-        }
-        if (!newTemplate){
-            tmplId = static_cast<FloskelTemplate*>(tmpl)->getTemplID();
-        }
-    } else if ( kat->type() == MaterialCatalog ) {
-        if ( newTemplate ) {
-            // FIXME
         }
     }
 
@@ -1038,8 +1038,10 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl, const QString&
 
         mRememberAmount = dp->amount();
 
-        if (tmplId > 0) {
-            kat->recordUsage(tmplId);
+        if (tmplId > 0 && tmpl) {
+            QPair<int, QDateTime> newUsage = kat->recordUsage(tmplId);
+            tmpl->setUseCounter(newUsage.first);
+            tmpl->setLastUsedDate(newUsage.second);
         }
 
         PositionViewWidget *widget = createPositionViewWidget( dp, newpos );
