@@ -234,7 +234,7 @@ void KraftViewRO::setup( DocGuardedPtr doc )
         if ( positions.reducedTaxSum( redTax ).toLong() > 0 ) {
             tmpl.createSubDictionary( "DISPLAY_SUM_BLOCK", "SECTION_REDUCED_TAX"  );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX_SUM" ),
-                           positions.reducedTaxSum( redTax ).toString() );
+                           positions.reducedTaxSum( redTax ).toLocaleString() );
             h.setNum( redTax, 'f', 1 );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX" ), h );
             tmpl.setValue( "SECTION_REDUCED_TAX", DOC_RO_TAG( "REDUCED_TAX_LABEL" ), i18n( "reduced VAT" ) );
@@ -243,7 +243,7 @@ void KraftViewRO::setup( DocGuardedPtr doc )
         if ( positions.fullTaxSum( fullTax ).toLong() > 0 ) {
             tmpl.createSubDictionary( "DISPLAY_SUM_BLOCK", "SECTION_FULL_TAX" );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX_SUM" ),
-                           positions.fullTaxSum( fullTax ).toString() );
+                           positions.fullTaxSum( fullTax ).toLocaleString() );
             h.setNum( fullTax, 'f', 1 );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX" ), h );
             tmpl.setValue( "SECTION_FULL_TAX", DOC_RO_TAG( "FULL_TAX_LABEL" ), i18n( "VAT" ) );
