@@ -66,7 +66,8 @@
 #include "setupassistant.h"
 #include "addressprovider.h"
 #include "alldocsview.h"
-
+#include "exportxrechnung.h"
+#include "ui_xrechnung.h"
 
 Portal::Portal(QWidget *parent, QCommandLineParser *commandLineParser, const char* name)
 : QMainWindow( parent ),
@@ -86,9 +87,9 @@ Portal::Portal(QWidget *parent, QCommandLineParser *commandLineParser, const cha
 
   mAddressProvider = new AddressProvider( this );
 
-  const QByteArray state = QByteArray::fromBase64( KraftSettings::self()->portalState().toAscii() );
+  const QByteArray state = QByteArray::fromBase64( KraftSettings::self()->portalState().toLatin1() );
   restoreState(state);
-  const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->portalGeometry().toAscii() );
+  const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->portalGeometry().toLatin1() );
   restoreGeometry(geo);
 
   // setAutoSaveSettings();
@@ -128,10 +129,12 @@ void Portal::initActions()
     _actNewDocument->setShortcuts(QKeySequence::New);
     connect(_actNewDocument, &QAction::triggered, this, &Portal::slotNewDocument);
 
+    newIcon = QIcon::fromTheme( "document-new-from-template");
     _actCopyDocument = new QAction(newIcon, i18n("&Copy Document"), this);
     // _actCopyDocument->setShortcuts();
     connect(_actCopyDocument, &QAction::triggered, this, &Portal::slotCopyCurrentDocument);
 
+    newIcon = QIcon::fromTheme( "document-export");
     _actFollowDocument = new QAction(newIcon, i18n("Create &Followup Document"), this);
     _actFollowDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_F ));
     connect(_actFollowDocument, &QAction::triggered, this, &Portal::slotFollowUpDocument);
@@ -141,7 +144,7 @@ void Portal::initActions()
     _actPrintDocument->setShortcut( QKeySequence::Print);
     connect(_actPrintDocument, &QAction::triggered, this, &Portal::slotPrintCurrentDocument);
 
-    newIcon = QIcon::fromTheme( "document-view");
+    newIcon = QIcon::fromTheme( "document-preview");
     _actViewDocument = new QAction(newIcon, i18n("Show Document"), this);
     _actViewDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
     connect(_actViewDocument, &QAction::triggered, this, &Portal::slotViewCurrentDocument);
@@ -151,7 +154,7 @@ void Portal::initActions()
     _actOpenDocument->setShortcut( QKeySequence::Open );
     connect(_actOpenDocument, &QAction::triggered, this, &Portal::slotOpenCurrentDocument);
     
-    newIcon = QIcon::fromTheme( "document-edit");
+    newIcon = QIcon::fromTheme( "file-library-symbolic");
     _actOpenArchivedDocument = new QAction(newIcon, i18n("Open Archived Document"), this);
     _actOpenArchivedDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_A ));
     connect(_actOpenArchivedDocument, &QAction::triggered, this, &Portal::slotArchivedDocExecuted);
@@ -161,6 +164,11 @@ void Portal::initActions()
     _actMailDocument->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_M ));
     connect(_actMailDocument, &QAction::triggered, this, &Portal::slotMailDocument);
 
+    newIcon = QIcon::fromTheme( "mail-forward");
+    _actXRechnung = new QAction(newIcon, i18n("Export XRechnung"), this);
+    _actXRechnung->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_R ));
+    connect(_actXRechnung, &QAction::triggered, this, &Portal::slotXRechnungCurrentDocument);
+
     newIcon = QIcon::fromTheme( "settings-configure");
     _actEditTemplates= new QAction(newIcon, i18n("Edit Tag Templates"), this);
     _actEditTemplates->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_E ));
@@ -197,6 +205,7 @@ void Portal::initActions()
     _actOpenDocument->setStatusTip( i18n( "Opens the document for editing" ) );
     _actViewDocument->setStatusTip( i18n( "Opens a read only view on the document." ) );
     _actMailDocument->setStatusTip( i18n( "Send document per mail" ) );
+    _actXRechnung->setStatusTip( i18n("Export invoice in XRechnung XML format."));
     _actEditTemplates->setStatusTip( i18n("Edit the available tag templates which can be assigned to document items.") );
     _actReconfDb->setStatusTip( i18n( "Configure the Database Kraft is working on." ) );
     _actOpenArchivedDocument->setStatusTip( i18n( "Open a viewer on an archived document" ) );
@@ -209,6 +218,7 @@ void Portal::initActions()
     _actMailDocument->setEnabled( false );
 
     _actOpenArchivedDocument->setEnabled( false );
+    _actXRechnung->setEnabled( false );
     // use the absolute path to your kraftui.rc file for testing purpose in createGUI();
     QString prjPath = QString::fromUtf8(qgetenv("KRAFT_HOME"));
 
@@ -225,6 +235,7 @@ void Portal::initActions()
     docMenu->addAction(_actViewDocument);
     if (!_readOnlyMode) docMenu->addAction(_actOpenDocument);
     docMenu->addAction(_actOpenArchivedDocument);
+    docMenu->addAction(_actXRechnung);
     if (!_readOnlyMode) {
         docMenu->addSeparator();
         docMenu->addAction(_actNewDocument);
@@ -264,6 +275,7 @@ void Portal::initActions()
         toolBar->addAction(_actMailDocument);
     } else {
         toolBar->addAction(_actOpenArchivedDocument);
+        toolBar->addAction(_actXRechnung);
         toolBar->addAction(_actViewDocument);
     }
 
@@ -291,6 +303,7 @@ void Portal::initView()
       menu->addAction( _actViewDocument );
       if (!_readOnlyMode) menu->addAction( _actOpenDocument );
       menu->addAction( _actOpenArchivedDocument );
+      menu->addAction( _actXRechnung);
       if (!_readOnlyMode) {
           menu->addSeparator();
           menu->addAction( _actNewDocument );
@@ -318,8 +331,9 @@ void Portal::initView()
              this, SLOT( slotViewDocument( const QString& ) ) );
     connect( m_portalView.data(), SIGNAL( openArchivedDocument( const ArchDocDigest& ) ),
              this, SLOT( slotOpenArchivedDoc( const ArchDocDigest& ) ) );
-    connect( m_portalView.data(),  SIGNAL( documentSelected( const QString& ) ),
-             this,  SLOT( slotDocumentSelected( const QString& ) ) );
+    connect( m_portalView.data(), &PortalView::exportXRechnungArchivedDocument,
+             this, &Portal::slotExportXRechnungArchivedDoc);
+    connect( m_portalView.data(), &PortalView::documentSelected, this, &Portal::slotDocumentSelected);
     connect( m_portalView.data(),  SIGNAL( archivedDocSelected( const ArchDocDigest& ) ),
              this,  SLOT( slotArchivedDocSelected( const ArchDocDigest& ) ) );
     setCentralWidget(m_portalView.data());
@@ -377,6 +391,7 @@ void Portal::slotStartupChecks()
         _actViewDocument->setEnabled( false );
         _actPrintDocument->setEnabled( false );
         _actOpenArchivedDocument->setEnabled( false );
+        _actXRechnung->setEnabled(false);
         _actMailDocument->setEnabled( false );
 
         slotStatusMsg( i18n( "Database Problem." ) );
@@ -452,8 +467,6 @@ void Portal::slotStartupChecks()
                  this, &Portal::slotDocConverted);
         connect( &_reportGenerator, &ReportGenerator::failure,
                  this, &Portal::slotDocConvertionFail);
-
-        slotStatusMsg();
     }
 }
 
@@ -625,6 +638,60 @@ void Portal::slotViewDocument( const QString& id )
 
 }
 
+void Portal::slotXRechnungCurrentDocument()
+{
+  // qDebug () << "printing document " << locId << endl;
+  ArchDocDigest dig = m_portalView->docDigestView()->currentLatestArchivedDoc();
+
+  slotExportXRechnungArchivedDoc(dig);
+}
+
+void Portal::slotExportXRechnungArchivedDoc(const ArchDocDigest& d)
+{
+    ExporterXRechnung *exporter = new ExporterXRechnung;
+    const QString tmplFile = exporter->templateFile();
+    QString err;
+
+    if (tmplFile.isEmpty()) {
+        err = i18n("XRechnung Template file not set. Please check the application settings!");
+    } else {
+        QFileInfo fi(tmplFile);
+        if (!fi.isFile()) {
+            err = i18n("The XRechnung template file can not be read!");
+        }
+    }
+
+    if (!err.isEmpty()) {
+        QMessageBox::warning(this, i18n("XRechnung Export"), err);
+        delete exporter;
+        return;
+    }
+
+    auto dia = new QDialog(this);
+    Ui::XRechnungDialog ui;
+    ui.setupUi(dia);
+
+    QDate today = QDate::currentDate();
+    ui._dueDateEdit->setDate(today.addDays(21));
+    ui._buyerRefEdit->setText("unknown");
+
+    if (dia->exec() == QDialog::Accepted) {
+        exporter->setDueDate(ui._dueDateEdit->date());
+        exporter->setBuyerRef(ui._buyerRefEdit->text());
+
+        connect(exporter, &ExporterXRechnung::xRechnungTmpFile, this, [=](const QString& fName) {
+            qDebug() << "This is the xrechnung file name." << fName;
+            const QString proposeName = QString("%1/xrechnung_%2.xml").arg(QDir::homePath()).arg(d.archDocIdent());
+            const QString f = QFileDialog::getSaveFileName(this, i18n("Save XRechnung"), proposeName);
+            QFile::copy(fName, f);
+            this->slotStatusMsg(i18n("Saved XRechnung to %1").arg(f));
+            exporter->deleteLater();
+        });
+        exporter->exportDocument(d);
+    }
+
+}
+
 void Portal::slotOpenArchivedDoc( const ArchDocDigest& d )
 {
   busyCursor( true );
@@ -674,7 +741,6 @@ void Portal::slotMailDocument()
 
     dbID archID = KraftDB::self()->archiveDocument( docPtr );
 
-    _clientId = docPtr->addressUid();
     busyCursor( true );
 
     _reportGenerator.createDocument(ReportFormat::PDFMail, ident, archID );
@@ -710,7 +776,7 @@ void Portal::openInMailer(const QString& fileName, const KContacts::Addressee& c
     if( KraftSettings::self()->mailUA().startsWith("xdg") ) {
         args.append( "--utf8");
         args.append( "--attach");
-        args.append(_pdfFileName );
+        args.append(fileName);
         if( !mailReceiver.isEmpty() ) {
             args.append( mailReceiver);
         }
@@ -732,7 +798,6 @@ void Portal::openInMailer(const QString& fileName, const KContacts::Addressee& c
     if (!QProcess::startDetached(prog, args)) {
         qDebug () << "Failed to start thunderbird composer!";
     }
-    _pdfFileName.clear();
 }
 
 /*
@@ -805,10 +870,10 @@ void Portal::slotOpenDocument( const QString& id )
     slotStatusMsg();
 }
 
-void Portal::slotDocumentSelected( const QString& doc )
+void Portal::slotDocumentSelected( const DocDigest& doc )
 {
     // qDebug() << "a doc was selected: " << doc << endl;
-    bool enable = !doc.isEmpty();
+    bool enable = !doc.id().isEmpty();
     _actViewDocument->setEnabled( enable );
     _actOpenDocument->setEnabled( (!_readOnlyMode) && enable );
     _actPrintDocument->setEnabled( (!_readOnlyMode) && enable );
@@ -816,8 +881,15 @@ void Portal::slotDocumentSelected( const QString& doc )
     _actMailDocument->setEnabled( (!_readOnlyMode) && enable );
     _actFollowDocument->setEnabled( (!_readOnlyMode) && enable );
 
-    _actOpenArchivedDocument->setEnabled( enable );
-
+    auto archDocs = doc.archDocDigestList();
+    if (archDocs.isEmpty()) {
+        _actOpenArchivedDocument->setEnabled(false);
+        _actXRechnung->setEnabled(false);
+    } else {
+        _actOpenArchivedDocument->setEnabled( enable );
+        ArchDocDigest archDoc = archDocs.at(0);
+        _actXRechnung->setEnabled(archDoc.hasXRechnungExport() && enable);
+    }
 }
 
 void Portal::slotArchivedDocExecuted()
@@ -830,6 +902,7 @@ void Portal::slotArchivedDocSelected( const ArchDocDigest& )
 {
   // slotDocumentSelected( QString() );
   _actOpenArchivedDocument->setEnabled( true );
+  _actXRechnung->setEnabled(true);
   _actViewDocument->setEnabled( false );
   _actOpenDocument->setEnabled( false );
   _actPrintDocument->setEnabled( false );
@@ -874,7 +947,7 @@ void Portal::createView( DocGuardedPtr doc )
 
   if( !mViewMap.contains(doc) ){
       KraftView *view = new KraftView( this );
-      const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->docEditGeometry().toAscii() );
+      const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->docEditGeometry().toLatin1() );
       view->restoreGeometry(geo);
       view->setup( doc );
       view->redrawDocument();
@@ -901,7 +974,7 @@ void Portal::createROView( DocGuardedPtr doc )
         KraftViewRO *view = new KraftViewRO( this );
         view->setup( doc );
         // view->redrawDocument();
-        const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->docViewROGeometry().toAscii() );
+        const QByteArray geo = QByteArray::fromBase64( KraftSettings::self()->docViewROGeometry().toLatin1() );
         view->restoreGeometry(geo);
         view->show();
         mViewMap[doc] = view;
