@@ -79,6 +79,8 @@ class Portal : public QMainWindow
   protected slots:
     void slotStartupChecks();
     void slotOpenArchivedDoc( const ArchDocDigest& );
+    void slotExportXRechnungArchivedDoc(const ArchDocDigest&);
+    void slotXRechnungCurrentDocument();
 
     void slotPrefsDialogFinished( int );
     void slotDocConverted(ReportFormat format, const QString& file,
@@ -122,7 +124,7 @@ class Portal : public QMainWindow
     void slotViewDocument( const QString& );
 
     void slotFollowUpDocument();
-    void slotDocumentSelected( const QString& );
+    void slotDocumentSelected( const DocDigest& );
     void slotArchivedDocExecuted();
     void slotArchivedDocSelected( const ArchDocDigest& );
     void slotPrintCurrentDocument();
@@ -165,6 +167,7 @@ class Portal : public QMainWindow
     QAction* _actFollowDocument;
     QAction* _actPrintDocument;
     QAction* _actMailDocument;
+    QAction* _actXRechnung;
     QAction* _actEditTemplates;
 
     QAction* _actOpenArchivedDocument;
@@ -176,8 +179,6 @@ class Portal : public QMainWindow
     QMap<QString, KatalogView*> mKatalogViews;
     QMap<KraftDoc*, KraftViewBase*> mViewMap;
 
-    QString _clientId;
-    QString _pdfFileName;
     AddressProvider *mAddressProvider;
     KContacts::Addressee myContact;
     PrefsDialog *_prefsDialog;
