@@ -35,6 +35,7 @@
 #include "defaultprovider.h"
 #include "reportgenerator.h"
 #include "texttemplate.h"
+#include "format.h"
 
 PortalView::PortalView(QWidget *parent, const char*)
     : QWidget( parent ),
@@ -202,24 +203,12 @@ QString PortalView::printKatLine( const QString& name, int cnt ) const
     if( details.countEntries == 0 ) {
         html += QString("<td colspan=\"2\"><span style=\"font-size:75%;\">%1</span></td>").arg(i18n("No templates yet."));
     } else {
-        QLocale *locale = DefaultProvider::self()->locale();
-        QString dateStr = locale->toString(details.maxModDate);
+        const QString dateStr = Format::toDateString(details.maxModDate.date(), Format::DateFormatGerman);
         html += QString("<td class=\"sub\" colspan=\"2\">") +
                 i18n("%1 templates in %2 chapters<br/>last modified at %3",
                 details.countEntries, details.countChapters, dateStr)
                 + QLatin1String("</td>");
     }
-#if 0
-    html += "<td align=\"center\"><a href=\"http://localhost/katalog.cgi?kat="+
-            name+"&action=xml\">";
-    html += i18n("XML Export");
-    html += "</td>";
-
-    html += "<td align=\"center\"><a href=\"http://localhost/katalog.cgi?kat="+
-            name+"&action=delete\">";
-    html += i18n("Remove");
-    html += "</td>";
-#endif
     html += "</tr>\n";
     return html;
 }
@@ -341,9 +330,9 @@ QString PortalView::systemView( const QString& htmlMsg ) const
 
   // external tools
   tmpl.setValue( "EXTERNAL_TOOLS_LABEL", i18n( "External Tools" ) );
-  tmpl.setValue( "RML2PDF_TOOL_LABEL", i18n( "RML to PDF conversion tool" ) );
-  QStringList trml2pdf = DefaultProvider::self()->findTrml2Pdf();
 
+  tmpl.setValue( "RML2PDF_TOOL_LABEL", i18n( "RML to PDF conversion tool" ) );
+  const QStringList trml2pdf = DefaultProvider::self()->findTrml2Pdf();
   QString trml2pdfValue = (trml2pdf.count() ? trml2pdf.join(" ") : i18n("not found!") );
   tmpl.setValue( "RML2PDF_TOOL", trml2pdfValue );
 
@@ -388,20 +377,20 @@ QWidget* PortalView::documentDigests()
   _allDocsView = new AllDocsView( w );
   b->addWidget( _allDocsView );
 
-  connect( _allDocsView, SIGNAL( createDocument() ),
-           this, SLOT( slotCreateDocument() ) );
-  connect( _allDocsView, SIGNAL( openDocument( const QString& ) ),
-           SIGNAL( openDocument( const QString& ) ) );
-  connect( _allDocsView, SIGNAL( viewDocument( const QString& ) ),
-           SIGNAL( viewDocument( const QString& ) ) );
-  connect( _allDocsView, SIGNAL( copyDocument( const QString& ) ),
-           SIGNAL( copyDocument( const QString& ) ) );
-  connect( _allDocsView, SIGNAL( openArchivedDocument( const ArchDocDigest& ) ),
-           SIGNAL( openArchivedDocument( const ArchDocDigest& ) ) );
-  connect( _allDocsView, SIGNAL( docSelected( const QString& ) ),
-           SIGNAL( documentSelected( const QString& ) ) );
-  connect( _allDocsView, SIGNAL( openArchivedDocument( const ArchDocDigest& ) ),
-           SIGNAL( archivedDocSelected( const ArchDocDigest& ) ) );
+  connect( _allDocsView, &AllDocsView::createDocument, this, &PortalView::slotCreateDocument);
+
+  connect( _allDocsView, &AllDocsView::openDocument, this, &PortalView::openDocument);
+  connect( _allDocsView, &AllDocsView::viewDocument, this, &PortalView::viewDocument);
+  connect( _allDocsView, &AllDocsView::copyDocument, this, &PortalView::copyDocument);
+
+  connect( _allDocsView, &AllDocsView::openArchivedDocument,
+           this, &PortalView::openArchivedDocument);
+  connect( _allDocsView, &AllDocsView::exportXRechnungArchivedDocument,
+           this, &PortalView::exportXRechnungArchivedDocument);
+  connect( _allDocsView, &AllDocsView::docSelected , this, &PortalView::documentSelected );
+  connect( _allDocsView, &AllDocsView::openArchivedDocument,
+           this, &PortalView::archivedDocSelected );
+
 
   return w;
  }
