@@ -33,6 +33,7 @@ class AllDocsView;
 class dbID;
 class PortalHtmlView;
 class ArchDocDigest;
+class DocDigest;
 
 class PortalView : public QWidget
 {
@@ -66,7 +67,8 @@ signals:
   void copyDocument( const QString& );
   void viewDocument( const QString& );
   void openArchivedDocument( const ArchDocDigest& );
-  void documentSelected( const QString& );
+  void exportXRechnungArchivedDocument( const ArchDocDigest&);
+  void documentSelected( const DocDigest& );
   void archivedDocSelected( const ArchDocDigest& );
 
 private:
