@@ -119,7 +119,7 @@ void ReportGenerator::createDocument( ReportFormat format, const QString& docID,
     _archDoc.loadFromDb(archId);
 
     // the next call also sets the watermark options
-    _tmplFile = findTemplateFile( _archDoc.docType() );
+    _tmplFile = findTemplateFile( _archDoc.docTypeStr() );
 
     if ( _tmplFile.isEmpty() ) {
         qDebug () << "tmplFile is empty, exit reportgenerator!";
@@ -300,6 +300,9 @@ void ReportGenerator::slotConverterError(PDFConverter::ConvError err)
     case PDFConverter::ConvError::NoReportLabMod:
         errMsg = i18n("The ReportLab python module is not installed.");
         break;
+    case PDFConverter::ConvError::NoPyPDFMod:
+        errMsg = i18n("The PyPDF2 python module is not installed.");
+        break;
     case PDFConverter::ConvError::SourceFileFail:
         errMsg = i18n("The source file can not be read.");
         break;
